@@ -9,6 +9,7 @@ __email__ = "pjmlantunes@gmail.com"
 
 
 from datetime import datetime
+from mongoengine import Q
 from mongoengine.errors import DoesNotExist, ValidationError
 from xtcryptosignals.tasks.models.history import History
 from xtcryptosignals.tasks.models.cfgi import CFGI
@@ -160,8 +161,10 @@ def get_chart_twitter(project, frequency):
         raise ValueError("Project is invalid.", 405)
 
     num_followers = []
-    for t in ProjectTwitter.objects(project=project)[:30]:
-        obj = t.to_dict()
+    for pt in ProjectTwitter.objects(
+        Q(project=project) & Q(num_followers__exists=True)
+    )[:30]:
+        obj = pt.to_dict()
         num_followers.append(
             [_normalize_ts(obj["created_on_ts"], "1d"), obj["num_followers"],]
         )
