@@ -26,6 +26,7 @@ BILAXY = "bilaxy"
 BITSTAMP = "bitstamp"
 KUCOIN = "kucoin"
 COINBASE_PRO = "coinbase_pro"
+LIQUID = "liquid"
 
 
 EXCHANGES = [
@@ -46,6 +47,7 @@ EXCHANGES = [
     BITSTAMP,
     KUCOIN,
     COINBASE_PRO,
+    LIQUID,
 ]
 
 
@@ -76,6 +78,12 @@ SYMBOLS_PER_EXCHANGE.append(
                 ("LTO", "USDT"),
                 ("LTO", "BTC"),
                 ("LTO", "BNB"),
+                ("REN", "USDT"),
+                ("REN", "BTC"),
+                ("KNC", "USDT"),
+                ("KNC", "BTC"),
+                ("LEND", "USDT"),
+                ("LEND", "BTC"),
             ],
         }
     }
@@ -131,6 +139,11 @@ SYMBOLS_PER_EXCHANGE.append(
     {OKCOIN: {"pairs": [("BTC", "USD"), ("ETH", "USD"), ("LTC", "USD"),]}}
 )
 
+# LIQUID
+SYMBOLS_PER_EXCHANGE.append(
+    {LIQUID: {"pairs": [("EWT", "BTC"), ("EWT", "ETH"),]}}
+)
+
 # Coinbene
 SYMBOLS_PER_EXCHANGE.append(
     {COINBENE: {"pairs": [("BTC", "USDT"), ("ETH", "USDT"), ("LTC", "USDT"),]}}
@@ -197,9 +210,19 @@ EXCHANGES_AND_PAIRS_OF_REFERENCE = {
     "HBAR": {"pair": "USDT", "name": BINANCE,},
     "BTMX": {"pair": "USDT", "name": BITMAX,},
     "LTO": {"pair": "USDT", "name": BINANCE,},
+    "KNC": {"pair": "USDT", "name": BINANCE,},
+    "LEND": {"pair": "USDT", "name": BINANCE,},
+    "REN": {"pair": "USDT", "name": BINANCE,},
     "IDEX": {"pair": "ETH", "name": IDEX,},
     "LQD": {"pair": "ETH", "name": BILAXY,},
     "CARD": {"pair": "ETH", "name": HOTBIT,},
+    "EWT": {"pair": "ETH", "name": LIQUID,},
 }
 
-# Checks EXCHANGES_AND_PAIRS_OF_REFERENCE against SYMBOLS_PER_EXCHANGE
+# Check to make sure that ALL configured symbols must have an
+# exchange and pair referenced
+from xtcryptosignals.common.utils import get_coin_tokens  # noqa: E402
+
+assert sorted(get_coin_tokens(SYMBOLS_PER_EXCHANGE)) == sorted(
+    list(EXCHANGES_AND_PAIRS_OF_REFERENCE.keys())
+)
