@@ -18,7 +18,7 @@ MONGODB_NAME = env.str("MONGODB_NAME")
 MONGODB_HOST = env.str("MONGODB_HOST")
 MONGODB_PORT = env.int("MONGODB_PORT")
 
-SERVER_ADDRESS = env.str("SERVER_ADDRESS")
+WEBSITE_ADDRESS = env.str("WEBSITE_ADDRESS")
 
 BROKER_URL = env.str("BROKER_URL")
 
