@@ -16,3 +16,7 @@ BINANCE_API_SECRET = ""
 KUCOIN_API_KEY = ""
 KUCOIN_API_SECRET = ""
 KUCOIN_API_PASSPHRASE = ""
+
+IDEX_API_KEY = ""
+IDEX_ADDRESS = ""
+IDEX_PRIVATE_KEY = ""
